build method
Describes the part of the user interface represented by this widget.
The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.
The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.
Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.
The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.
The implementation of this method must only depend on:
- the fields of the widget, which themselves must not change over time, and
- any ambient state obtained from the
contextusing BuildContext.dependOnInheritedWidgetOfExactType.
If a widget's build method is to depend on anything else, use a StatefulWidget instead.
See also:
- StatelessWidget, which contains the discussion on performance considerations.
Implementation
@override
Widget build(BuildContext context) {
if (children.isEmpty) return const SizedBox.shrink();
if (children.length == 1) return children.first;
final List<Widget> groupedButtons = [];
for (int i = 0; i < children.length; i++) {
final button = children[i];
final bool isFirst = i == 0;
final bool isLast = i == children.length - 1;
final BsButtonSize finalSize = groupSize ?? button.size;
// 1. Calculate specific radius for the position in the group
final BorderRadius groupRadius = _calculateRadius(
finalSize,
isFirst,
isLast,
);
// 2. We "clone" the button and inject the new radius
Widget modifiedButton = BsButton(
key: button.key,
label: button.label,
onPressed: button.onPressed,
variant: button.variant,
size: finalSize,
isLoading: button.isLoading,
icon: button.icon,
fullWidth: button.fullWidth,
badge: button.badge,
badgePosition: button.badgePosition,
customBorderRadius: groupRadius, // Here we override the corners!
);
// 3. Simulate CSS "margin-left: -1px"
// If we place outline buttons next to each other, double 2px borders are otherwise created.
// We move each button (except the first one) visually by 1px to the left (or top).
if (i > 0) {
modifiedButton = Transform.translate(
offset: vertical ? const Offset(0, -1) : const Offset(-1, 0),
child: modifiedButton,
);
}
groupedButtons.add(modifiedButton);
}
// 4. Render in Row or Column
return vertical
? Column(
mainAxisSize: MainAxisSize.min,
crossAxisAlignment: CrossAxisAlignment.stretch,
children: groupedButtons,
)
: Row(mainAxisSize: MainAxisSize.min, children: groupedButtons);
}