padding property
Padding around the close icon to increase the tap target.
Defaults to EdgeInsets.all(4.0).
Implementation
final EdgeInsetsGeometry padding;
Padding around the close icon to increase the tap target.
Defaults to EdgeInsets.all(4.0).
final EdgeInsetsGeometry padding;