white property
Explicitly forces the button color to be white.
Useful for placing the close button on dark backgrounds.
Implementation
final bool white;
Explicitly forces the button color to be white.
Useful for placing the close button on dark backgrounds.
final bool white;