BsCard constructor

const BsCard({
  1. Key? key,
  2. Widget? header,
  3. Widget? body,
  4. Widget? footer,
  5. List<Widget>? children,
  6. Widget? image,
  7. BsCardImagePosition imagePosition = BsCardImagePosition.top,
  8. int imageFlex = 4,
  9. int contentFlex = 8,
  10. BsVariant? variant,
  11. BsVariant? borderVariant,
  12. Color? color,
  13. Color? borderColor,
  14. BorderRadius? borderRadius,
  15. double? width,
  16. double? height,
})

Creates a BsCard.

You can build cards using either direct convenience parameters (header, body, footer, image) or customize it completely by providing the children parameter.

Implementation

const BsCard({
  super.key,
  this.header,
  this.body,
  this.footer,
  this.children,
  this.image,
  this.imagePosition = BsCardImagePosition.top,
  this.imageFlex = 4,
  this.contentFlex = 8,
  this.variant,
  this.borderVariant,
  this.color,
  this.borderColor,
  this.borderRadius,
  this.width,
  this.height,
});