children property

List<Widget>? children
final

A list of widgets to stack inside the card vertically.

If provided, this overrides the default header, body, footer layout list.

Implementation

final List<Widget>? children;