contentFlex property
The flex ratio of the content in a horizontal card layout (left or right).
Defaults to 8 (representing .col-md-8 in Bootstrap).
Implementation
final int contentFlex;
The flex ratio of the content in a horizontal card layout (left or right).
Defaults to 8 (representing .col-md-8 in Bootstrap).
final int contentFlex;