imageFlex property
The flex ratio of the image in a horizontal card layout (left or right).
Defaults to 4 (representing .col-md-4 in Bootstrap).
Implementation
final int imageFlex;
The flex ratio of the image in a horizontal card layout (left or right).
Defaults to 4 (representing .col-md-4 in Bootstrap).
final int imageFlex;