aspectRatio property
An aspect ratio to constrain the carousel size dynamically.
If provided, wraps the carousel in an AspectRatio widget.
Implementation
final double? aspectRatio;
An aspect ratio to constrain the carousel size dynamically.
If provided, wraps the carousel in an AspectRatio widget.
final double? aspectRatio;