height property
A fixed height for the carousel.
If both height and aspectRatio are null, defaults to a height of 300.0.
Implementation
final double? height;
A fixed height for the carousel.
If both height and aspectRatio are null, defaults to a height of 300.0.
final double? height;