pauseOnHover property
Whether to pause autoplay when the user hovers over the carousel.
Defaults to true.
Implementation
final bool pauseOnHover;
Whether to pause autoplay when the user hovers over the carousel.
Defaults to true.
final bool pauseOnHover;