dark property
Forces the dark theme behavior if true, light theme if false, or auto-detects from the context if null (default).
Implementation
final bool? dark;
Forces the dark theme behavior if true, light theme if false, or auto-detects from the context if null (default).
final bool? dark;