onChanged property
Called when the user initiates a change to the TextField's value: when they have inserted or deleted text.
Implementation
final ValueChanged<String>? onChanged;
Called when the user initiates a change to the TextField's value: when they have inserted or deleted text.
final ValueChanged<String>? onChanged;