onFieldSubmitted property
Called when the user indicates that they are done editing the text in the field.
Implementation
final ValueChanged<String>? onFieldSubmitted;
Called when the user indicates that they are done editing the text in the field.
final ValueChanged<String>? onFieldSubmitted;