captionAlignment property
How to align the caption horizontally.
If null, it defaults to the start of the figure.
Implementation
final AlignmentGeometry? captionAlignment;
How to align the caption horizontally.
If null, it defaults to the start of the figure.
final AlignmentGeometry? captionAlignment;