fluid property
Whether the image should be responsive.
If true, the image will scale with its parent's width (max-width: 100%).
Implementation
final bool fluid;
Whether the image should be responsive.
If true, the image will scale with its parent's width (max-width: 100%).
final bool fluid;