thumbnail property
Whether the image should be rendered as a thumbnail.
Adds a 1px border, some padding, and rounded corners.
Implementation
final bool thumbnail;
Whether the image should be rendered as a thumbnail.
Adds a 1px border, some padding, and rounded corners.
final bool thumbnail;