onClosePressed property
Action callback when the close button is pressed. If null, default is dismissing the modal with Navigator.pop.
Implementation
final VoidCallback? onClosePressed;
Action callback when the close button is pressed. If null, default is dismissing the modal with Navigator.pop.
final VoidCallback? onClosePressed;