background property
Custom background color. If null, it defaults to light or dark background depending on theme.
Implementation
final Color? background;
Custom background color. If null, it defaults to light or dark background depending on theme.
final Color? background;