semanticsValue property
Optional custom semantics value string representation for screen readers.
Defaults to "${value.toStringAsFixed(0)}%".
Implementation
final String? semanticsValue;
Optional custom semantics value string representation for screen readers.
Defaults to "${value.toStringAsFixed(0)}%".
final String? semanticsValue;