columnWidths property
How the horizontal space should be distributed among the columns.
Implementation
final Map<int, TableColumnWidth>? columnWidths;
How the horizontal space should be distributed among the columns.
final Map<int, TableColumnWidth>? columnWidths;