defaultColumnWidth property
How to determine the width of columns that are not specified in columnWidths.
Implementation
final TableColumnWidth defaultColumnWidth;
How to determine the width of columns that are not specified in columnWidths.
final TableColumnWidth defaultColumnWidth;