BsTableFoot class

A configuration object for a table foot section.

Constructors

BsTableFoot({BsVariant? variant, BsTableVerticalAlign? verticalAlign, required List<BsTableRow> rows})
Creates a BsTableFoot.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
rows → List<BsTableRow>
The rows in the table foot.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variant → BsVariant?
The variant for the entire foot section.
final
verticalAlign → BsTableVerticalAlign?
The default vertical alignment for cells in the foot.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited