BsTableHead class

A configuration object for a table head section.

Constructors

BsTableHead({BsVariant? variant, BsTableVerticalAlign? verticalAlign, required List<BsTableRow> rows})
Creates a BsTableHead.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
rows → List<BsTableRow>
The rows in the table head.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variant → BsVariant?
The variant for the entire head section.
final
verticalAlign → BsTableVerticalAlign?
The default vertical alignment for cells in the head.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited