BsHeading constructor

const BsHeading(
  1. String text, {
  2. Key? key,
  3. BsHeadingLevel level = BsHeadingLevel.h1,
  4. Color? color,
  5. TextAlign? textAlign,
  6. bool removeMargin = false,
})

Creates a BsHeading widget.

The text parameter is required and represents the heading's content. The level defaults to BsHeadingLevel.h1. The removeMargin parameter removes the default bottom margin if set to true.

Implementation

const BsHeading(
  this.text, {
  super.key,
  this.level = BsHeadingLevel.h1,
  this.color,
  this.textAlign,
  this.removeMargin = false,
});