level property
The level of the heading (from BsHeadingLevel.h1 to BsHeadingLevel.h6).
Determines the font size of the heading based on Bootstrap typography tokens.
Implementation
final BsHeadingLevel level;
The level of the heading (from BsHeadingLevel.h1 to BsHeadingLevel.h6).
Determines the font size of the heading based on Bootstrap typography tokens.
final BsHeadingLevel level;