removeMargin property
Whether to remove the default bottom margin (0.5rem / 8px).
By default, a bottom margin is applied using pb2() spacing extension.
Implementation
final bool removeMargin;
Whether to remove the default bottom margin (0.5rem / 8px).
By default, a bottom margin is applied using pb2() spacing extension.
final bool removeMargin;