BsBreakpoints class abstract

Bootstrap 5 Breakpoints — exactly from the documentation. Source: https://getbootstrap.com/docs/5.3/layout/breakpoints/

Bootstrap is "mobile first" — meaning you define for small screens first and overwrite for larger ones.

Constructors

BsBreakpoints()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

containerLg → const double
containerMd → const double
containerSm → const double
containerXl → const double
containerXxl → const double
lg → const double
md → const double
sm → const double
xl → const double
xxl → const double