BsAlertAnimation enum

Animation types for showing/hiding BsAlert.

Inheritance
Available extensions

Values

none → const BsAlertAnimation

No animation.

fade → const BsAlertAnimation

Fade in/out.

slideTop → const BsAlertAnimation

Slide from top.

slideBottom → const BsAlertAnimation

Slide from bottom.

slideLeft → const BsAlertAnimation

Slide from left.

slideRight → const BsAlertAnimation

Slide from right.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BsAlertAnimation>
A constant List of the values in this enum, in order of their declaration.