BsCardImagePosition enum

Image positions for BsCard.

Inheritance
Available extensions

Values

top → const BsCardImagePosition

Image at the top of the card.

bottom → const BsCardImagePosition

Image at the bottom of the card.

overlay → const BsCardImagePosition

Image as background overlay.

left → const BsCardImagePosition

Image on the left side of the card.

Image on the right side of the card.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<BsCardImagePosition>
A constant List of the values in this enum, in order of their declaration.