BsColAlignSelf enum
Vertical alignment options for an individual BsCol column, overriding the row's alignment.
Values
- auto → const BsColAlignSelf
-
Inherits alignment from the parent BsRow.
- start → const BsColAlignSelf
-
Align this column to the top.
- center → const BsColAlignSelf
-
Center this column vertically.
- end → const BsColAlignSelf
-
Align this column to the bottom.
- stretch → const BsColAlignSelf
-
Stretch this column to fill the row height.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BsColAlignSelf> - A constant List of the values in this enum, in order of their declaration.