BsDropdownAlignment enum

Alignment of the dropdown menu relative to its trigger.

Inheritance
Available extensions

Values

start → const BsDropdownAlignment

Aligns the start edge of the menu with the start of the trigger (default).

end → const BsDropdownAlignment

Aligns the end edge of the menu with the end of the trigger.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BsDropdownAlignment>
A constant List of the values in this enum, in order of their declaration.