BsDropdownDirection enum

Direction in which the dropdown menu opens.

Inheritance
Available extensions

Values

down → const BsDropdownDirection

Opens below the trigger (default).

up → const BsDropdownDirection

Opens above the trigger (.dropup).

end → const BsDropdownDirection

Opens to the right of the trigger (.dropend).

start → const BsDropdownDirection

Opens to the left of the trigger (.dropstart).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BsDropdownDirection>
A constant List of the values in this enum, in order of their declaration.