BsIconVariant enum

Color variants for icons.

Inheritance
Available extensions

Values

primary → const BsIconVariant

Primary icon color.

secondary → const BsIconVariant

Secondary icon color.

success → const BsIconVariant

Success icon color.

danger → const BsIconVariant

Danger icon color.

warning → const BsIconVariant

Warning icon color.

info → const BsIconVariant

Info icon color.

light → const BsIconVariant

Light icon color.

dark → const BsIconVariant

Dark icon color.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BsIconVariant>
A constant List of the values in this enum, in order of their declaration.