BsNavbarExpand enum

Defines the expand behavior of a Bootstrap navbar.

Inheritance
Available extensions

Values

always → const BsNavbarExpand

Always expand the navbar (horizontal layout, no collapse/toggler).

sm → const BsNavbarExpand

Expand on screens wider than sm (>= 576px).

md → const BsNavbarExpand

Expand on screens wider than md (>= 768px).

lg → const BsNavbarExpand

Expand on screens wider than lg (>= 992px).

xl → const BsNavbarExpand

Expand on screens wider than xl (>= 1200px).

xxl → const BsNavbarExpand

Expand on screens wider than xxl (>= 1400px).

never → const BsNavbarExpand

Never expand the navbar (always collapsed with toggler).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BsNavbarExpand>
A constant List of the values in this enum, in order of their declaration.