BsPlacement enum

Generic placement options for overlay components like tooltips and popovers.

Inheritance
Available extensions

Values

top → const BsPlacement

Placed above the target.

bottom → const BsPlacement

Placed below the target.

start → const BsPlacement

Placed to the left of the target (in LTR).

end → const BsPlacement

Placed to the right of the target (in LTR).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BsPlacement>
A constant List of the values in this enum, in order of their declaration.