BsRadius class abstract
Bootstrap 5 Border-Radius values. Source: https://getbootstrap.com/docs/5.3/utilities/borders/#border-radius
Constructors
- BsRadius()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- lg → const BorderRadius
- md → const BorderRadius
- none → const BorderRadius
- pill → const BorderRadius
- sm → const BorderRadius