BsTransitions class abstract
Bootstrap 5 Transition and Animation Tokens. Source: Bootstrap _variables.scss
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- baseCurve → const Curve
- $transition-base curve (ease-in-out)
- baseDuration → const Duration
- Base transition duration (e.g. colors, shadows, borders) Default: 200ms
- carouselDuration → const Duration
- Carousel slide transition duration Default: 600ms
- collapseCurve → const Curve
- $transition-collapse curve (ease)
- collapseDuration → const Duration
- Collapse transition duration (e.g. accordions, collapse, nav toggles) Default: 350ms
- fadeCurve → const Curve
- $transition-fade curve (linear)
- fadeDuration → const Duration
- Fade transition duration (e.g. tooltips, popovers, simple opacity changes) Default: 150ms
- modalDuration → const Duration
- Modal / Offcanvas transition duration Default: 300ms
- placeholderDuration → const Duration
- Placeholder shimmering animation duration Default: 2000ms
- progressDuration → const Duration
- Progress bar striping animation duration Default: 1000ms
- spinnerDuration → const Duration
- Spinner rotation duration Default: 750ms
- toastDuration → const Duration
- Toast slide/fade transition duration Default: 300ms