alignBottom method
Aligns the widget to the bottom center of its parent.
Implementation
Widget alignBottom() => Align(
alignment: Alignment.bottomCenter,
child: this,
);
Aligns the widget to the bottom center of its parent.
Widget alignBottom() => Align(
alignment: Alignment.bottomCenter,
child: this,
);