alignTop method
Aligns the widget to the top center of its parent.
Implementation
Widget alignTop() => Align(
alignment: Alignment.topCenter,
child: this,
);
Aligns the widget to the top center of its parent.
Widget alignTop() => Align(
alignment: Alignment.topCenter,
child: this,
);