spinner property
String
get
spinner
Resolves the screen reader label for the spinner status.
Implementation
String get spinner => translate('spinner', fallback: 'Loading...');
Resolves the screen reader label for the spinner status.
String get spinner => translate('spinner', fallback: 'Loading...');