BsSpacingExtension extension

Extension on Widget to provide Bootstrap-like spacing utilities.

This extension allows for concise application of padding and margin to widgets, mirroring Bootstrap's p-*, m-*, etc., utility classes.

Example:

Text('Hello').p3();  // Applies standard padding level 3 (1rem/16px)
Text('World').mb2(); // Applies standard margin-bottom level 2 (0.5rem/8px)
on

Methods

m(double value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies uniform margin on all sides.
m0() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies zero margin on all sides.
m1() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies uniform margin of BsSpacing.s1 on all sides.
m2() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies uniform margin of BsSpacing.s2 on all sides.
m3() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies uniform margin of BsSpacing.s3 on all sides.
m4() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies uniform margin of BsSpacing.s4 on all sides.
m5() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies uniform margin of BsSpacing.s5 on all sides.
mAuto() Widget

Available on Widget, provided by the BsSpacingExtension extension

Centers the widget horizontally and vertically, matching m-auto.
mb(double value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies margin only to the bottom side.
mb0() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies zero margin to the bottom side.
mb1() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies bottom margin of BsSpacing.s1.
mb2() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies bottom margin of BsSpacing.s2.
mb3() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies bottom margin of BsSpacing.s3.
mb4() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies bottom margin of BsSpacing.s4.
mb5() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies bottom margin of BsSpacing.s5.
mbAuto() Widget

Available on Widget, provided by the BsSpacingExtension extension

Aligns the widget to the top of its parent, matching mb-auto in vertical layout.
me(double value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies margin only to the end (right) side.
me0() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies zero margin to the end side.
me1() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies end (right) margin of BsSpacing.s1.
me2() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies end (right) margin of BsSpacing.s2.
me3() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies end (right) margin of BsSpacing.s3.
me4() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies end (right) margin of BsSpacing.s4.
me5() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies end (right) margin of BsSpacing.s5.
meAuto() Widget

Available on Widget, provided by the BsSpacingExtension extension

Aligns the widget to the start (left) of its parent, matching me-auto in horizontal layout.
ms(double value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies margin only to the start (left) side.
ms0() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies zero margin to the start side.
ms1() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies start (left) margin of BsSpacing.s1.
ms2() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies start (left) margin of BsSpacing.s2.
ms3() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies start (left) margin of BsSpacing.s3.
ms4() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies start (left) margin of BsSpacing.s4.
ms5() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies start (left) margin of BsSpacing.s5.
msAuto() Widget

Available on Widget, provided by the BsSpacingExtension extension

Aligns the widget to the end (right) of its parent, matching ms-auto in horizontal layout.
mt(double value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies margin only to the top side.
mt0() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies zero margin to the top side.
mt1() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies top margin of BsSpacing.s1.
mt2() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies top margin of BsSpacing.s2.
mt3() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies top margin of BsSpacing.s3.
mt4() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies top margin of BsSpacing.s4.
mt5() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies top margin of BsSpacing.s5.
mtAuto() Widget

Available on Widget, provided by the BsSpacingExtension extension

Aligns the widget to the bottom of its parent, matching mt-auto in vertical layout.
mx(double value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies horizontal margin (left and right).
mx0() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies zero horizontal margin (left and right).
mx1() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies horizontal margin (left and right) of BsSpacing.s1.
mx2() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies horizontal margin (left and right) of BsSpacing.s2.
mx3() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies horizontal margin (left and right) of BsSpacing.s3.
mx4() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies horizontal margin (left and right) of BsSpacing.s4.
mx5() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies horizontal margin (left and right) of BsSpacing.s5.
mxAuto() Widget

Available on Widget, provided by the BsSpacingExtension extension

Centers the widget horizontally within its parent, matching mx-auto.
my(double value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies vertical margin (top and bottom).
my0() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies zero vertical margin (top and bottom).
my1() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies vertical margin (top and bottom) of BsSpacing.s1.
my2() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies vertical margin (top and bottom) of BsSpacing.s2.
my3() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies vertical margin (top and bottom) of BsSpacing.s3.
my4() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies vertical margin (top and bottom) of BsSpacing.s4.
my5() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies vertical margin (top and bottom) of BsSpacing.s5.
myAuto() Widget

Available on Widget, provided by the BsSpacingExtension extension

Centers the widget vertically within its parent, matching my-auto.
p(double value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies uniform padding on all sides.
p0() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies zero padding on all sides.
p1() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies uniform padding of BsSpacing.s1 on all sides.
p2() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies uniform padding of BsSpacing.s2 on all sides.
p3() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies uniform padding of BsSpacing.s3 on all sides.
p4() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies uniform padding of BsSpacing.s4 on all sides.
p5() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies uniform padding of BsSpacing.s5 on all sides.
padding(EdgeInsets value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies custom EdgeInsets as padding.
pb(double value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies padding only to the bottom side.
pb0() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies zero padding to the bottom side.
pb1() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies bottom padding of BsSpacing.s1.
pb2() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies bottom padding of BsSpacing.s2.
pb3() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies bottom padding of BsSpacing.s3.
pb4() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies bottom padding of BsSpacing.s4.
pb5() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies bottom padding of BsSpacing.s5.
pe(double value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies padding only to the end (right) side.
pe0() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies zero padding to the end side.
pe1() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies end (right) padding of BsSpacing.s1.
pe2() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies end (right) padding of BsSpacing.s2.
pe3() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies end (right) padding of BsSpacing.s3.
pe4() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies end (right) padding of BsSpacing.s4.
pe5() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies end (right) padding of BsSpacing.s5.
ps(double value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies padding only to the start (left) side.
ps0() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies zero padding to the start side.
ps1() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies start (left) padding of BsSpacing.s1.
ps2() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies start (left) padding of BsSpacing.s2.
ps3() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies start (left) padding of BsSpacing.s3.
ps4() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies start (left) padding of BsSpacing.s4.
ps5() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies start (left) padding of BsSpacing.s5.
pt(double value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies padding only to the top side.
pt0() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies zero padding to the top side.
pt1() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies top padding of BsSpacing.s1.
pt2() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies top padding of BsSpacing.s2.
pt3() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies top padding of BsSpacing.s3.
pt4() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies top padding of BsSpacing.s4.
pt5() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies top padding of BsSpacing.s5.
px(double value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies horizontal padding (left and right).
px0() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies zero horizontal padding (left and right).
px1() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies horizontal padding (left and right) of BsSpacing.s1.
px2() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies horizontal padding (left and right) of BsSpacing.s2.
px3() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies horizontal padding (left and right) of BsSpacing.s3.
px4() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies horizontal padding (left and right) of BsSpacing.s4.
px5() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies horizontal padding (left and right) of BsSpacing.s5.
py(double value) Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies vertical padding (top and bottom).
py0() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies zero vertical padding (top and bottom).
py1() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies vertical padding (top and bottom) of BsSpacing.s1.
py2() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies vertical padding (top and bottom) of BsSpacing.s2.
py3() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies vertical padding (top and bottom) of BsSpacing.s3.
py4() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies vertical padding (top and bottom) of BsSpacing.s4.
py5() Widget

Available on Widget, provided by the BsSpacingExtension extension

Applies vertical padding (top and bottom) of BsSpacing.s5.