BsCard constructor
const
BsCard({
- Key? key,
- Widget? header,
- Widget? body,
- List<
Widget> ? children, - Widget? image,
- BsCardImagePosition imagePosition = BsCardImagePosition.top,
- int imageFlex = 4,
- int contentFlex = 8,
- BsVariant? variant,
- BsVariant? borderVariant,
- Color? color,
- Color? borderColor,
- BorderRadius? borderRadius,
- double? width,
- double? height,
Creates a BsCard.
You can build cards using either direct convenience parameters (header, body, footer, image)
or customize it completely by providing the children parameter.
Implementation
const BsCard({
super.key,
this.header,
this.body,
this.footer,
this.children,
this.image,
this.imagePosition = BsCardImagePosition.top,
this.imageFlex = 4,
this.contentFlex = 8,
this.variant,
this.borderVariant,
this.color,
this.borderColor,
this.borderRadius,
this.width,
this.height,
});