BsScrollspy class
A widget that implements the Bootstrap Scrollspy behavior.
It listens to the scrolling events of its child via the provided controller and calculates which registered target is currently visible in the viewport.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- BsScrollspy
- Available extensions
Constructors
- BsScrollspy({Key? key, required BsScrollspyController controller, required Widget child, double activationMargin = 50.0})
-
Creates a Bootstrap Scrollspy component.
const
Properties
- activationMargin → double
-
The vertical margin (in logical pixels) from the top of the container
where a target is considered "active". Defaults to 50.0.
This acts similarly to the
rootMarginin Bootstrap.final - child → Widget
-
The scrollable child, typically a SingleChildScrollView or ListView.
final
- controller → BsScrollspyController
-
The controller that manages the active target and scrolling.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
align(
AlignmentGeometry alignment, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsAlignmentExtension extension
Aligns the widget within its parent using the givenalignment. -
alignBaseline(
{TextBaseline baseline = TextBaseline.alphabetic}) → WidgetSpan -
Available on Widget, provided by the BsVerticalAlignExtension extension
Aligns the baseline of the element with the baseline of its parent. -
alignBottom(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsAlignmentExtension extension
Aligns the widget to the bottom center of its parent. -
alignBottomInline(
) → WidgetSpan -
Available on Widget, provided by the BsVerticalAlignExtension extension
Aligns the bottom of the element with the bottom of the lowest element on the line. -
alignEnd(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsAlignmentExtension extension
Aligns the widget to the end (right) of its parent. -
alignMiddle(
) → WidgetSpan -
Available on Widget, provided by the BsVerticalAlignExtension extension
Centers the element vertically within the line. -
alignStart(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsAlignmentExtension extension
Aligns the widget to the start (left) of its parent. -
alignTextBottom(
{TextBaseline baseline = TextBaseline.alphabetic}) → WidgetSpan -
Available on Widget, provided by the BsVerticalAlignExtension extension
Aligns the bottom of the element with the bottom of the parent element's font. -
alignTextTop(
{TextBaseline baseline = TextBaseline.alphabetic}) → WidgetSpan -
Available on Widget, provided by the BsVerticalAlignExtension extension
Aligns the top of the element with the top of the parent element's font. -
alignTop(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsAlignmentExtension extension
Aligns the widget to the top center of its parent. -
alignTopInline(
) → WidgetSpan -
Available on Widget, provided by the BsVerticalAlignExtension extension
Aligns the top of the element with the top of the tallest element on the line. -
border(
{Color? color, double width = 1.0}) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Adds a default border on all sides, matching.border. -
border0(
) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Removes all borders, matching.border-0. -
borderBottom(
{Color? color, double width = 1.0}) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Adds a border to the bottom side, matching.border-bottom. -
borderEnd(
{Color? color, double width = 1.0}) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Adds a border to the end (right) side, matching.border-end. -
borderStart(
{Color? color, double width = 1.0}) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Adds a border to the start (left) side, matching.border-start. -
borderTop(
{Color? color, double width = 1.0}) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Adds a border to the top side, matching.border-top. -
borderVariant(
BuildContext context, BsVariant variant, {double width = 1.0}) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Colors the border based on the theme color variant, matching.border-*. -
center(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsAlignmentExtension extension
Centers the widget within its parent. -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< BsScrollspy> -
Creates the mutable state for this widget at a given location in the tree.
override
-
dBlock(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsDisplayExtension extension
Convenient alias forgone(false). Maps to Bootstrap's.d-block. If a breakpoint is provided, it shows the widget from that breakpoint and up, and hides it on smaller screens (acting as a combination ofd-none d-{bp}-block). -
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
dNone(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsDisplayExtension extension
Convenient alias forgone(true). Maps to Bootstrap's.d-none. If a breakpoint is provided, it hides the widget from that breakpoint and up. -
expanded(
[int flex = 1]) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Wraps the widget in an Expanded widget. -
gone(
bool gone, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsDisplayExtension extension
Hides the widget and removes it from the layout ifgoneis true. -
h(
double height) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets a fixed height for the widget. -
h100(
) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets the height to 100% (double.infinity). -
h25(
) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets the height to 25% of parent (FractionallySizedBox). -
h50(
) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets the height to 50% of parent (FractionallySizedBox). -
h75(
) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets the height to 75% of parent (FractionallySizedBox). -
m(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies all margin. -
m0(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies zero all margin. -
m1(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies all margin of BsSpacing.s1. -
m2(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies all margin of BsSpacing.s2. -
m3(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies all margin of BsSpacing.s3. -
m4(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies all margin of BsSpacing.s4. -
m5(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies all margin of BsSpacing.s5. -
mAuto(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Centers the widget horizontally and vertically, matchingm-auto. -
mb(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies bottom margin. -
mb0(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies zero bottom margin. -
mb1(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies bottom margin of BsSpacing.s1. -
mb2(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies bottom margin of BsSpacing.s2. -
mb3(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies bottom margin of BsSpacing.s3. -
mb4(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies bottom margin of BsSpacing.s4. -
mb5(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies bottom margin of BsSpacing.s5. -
mbAuto(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Aligns the widget to the top of its parent, matchingmb-autoin vertical layout. -
me(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies right margin. -
me0(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies zero right margin. -
me1(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies right margin of BsSpacing.s1. -
me2(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies right margin of BsSpacing.s2. -
me3(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies right margin of BsSpacing.s3. -
me4(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies right margin of BsSpacing.s4. -
me5(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies right margin of BsSpacing.s5. -
meAuto(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Aligns the widget to the start (left) of its parent, matchingme-autoin horizontal layout. -
minH100(
) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets min-height to 100% of parent. -
minVh100(
BuildContext context) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets min-height to 100vh (100% of viewport height). -
minVh50(
BuildContext context) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets min-height to 50vh (50% of viewport height). -
minVw100(
BuildContext context) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets min-width to 100vw (100% of viewport width). -
minVw50(
BuildContext context) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets min-width to 50vw (50% of viewport width). -
minW100(
) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets min-width to 100% of parent. -
ms(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies left margin. -
ms0(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies zero left margin. -
ms1(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies left margin of BsSpacing.s1. -
ms2(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies left margin of BsSpacing.s2. -
ms3(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies left margin of BsSpacing.s3. -
ms4(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies left margin of BsSpacing.s4. -
ms5(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies left margin of BsSpacing.s5. -
msAuto(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Aligns the widget to the end (right) of its parent, matchingms-autoin horizontal layout. -
mt(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies top margin. -
mt0(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies zero top margin. -
mt1(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies top margin of BsSpacing.s1. -
mt2(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies top margin of BsSpacing.s2. -
mt3(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies top margin of BsSpacing.s3. -
mt4(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies top margin of BsSpacing.s4. -
mt5(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies top margin of BsSpacing.s5. -
mtAuto(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Aligns the widget to the bottom of its parent, matchingmt-autoin vertical layout. -
mx(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies horizontal margin. -
mx0(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies zero horizontal margin. -
mx1(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies horizontal margin of BsSpacing.s1. -
mx2(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies horizontal margin of BsSpacing.s2. -
mx3(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies horizontal margin of BsSpacing.s3. -
mx4(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies horizontal margin of BsSpacing.s4. -
mx5(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies horizontal margin of BsSpacing.s5. -
mxAuto(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Centers the widget horizontally within its parent, matchingmx-auto. -
my(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies vertical margin. -
my0(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies zero vertical margin. -
my1(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies vertical margin of BsSpacing.s1. -
my2(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies vertical margin of BsSpacing.s2. -
my3(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies vertical margin of BsSpacing.s3. -
my4(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies vertical margin of BsSpacing.s4. -
my5(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies vertical margin of BsSpacing.s5. -
myAuto(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Centers the widget vertically within its parent, matchingmy-auto. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
opacity(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsDisplayExtension extension
Sets the opacity of the widget. -
p(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies all padding. -
p0(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies zero all padding. -
p1(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies all padding of BsSpacing.s1. -
p2(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies all padding of BsSpacing.s2. -
p3(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies all padding of BsSpacing.s3. -
p4(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies all padding of BsSpacing.s4. -
p5(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies all padding of BsSpacing.s5. -
padding(
EdgeInsets value) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies custom EdgeInsets as padding. -
pb(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies bottom padding. -
pb0(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies zero bottom padding. -
pb1(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies bottom padding of BsSpacing.s1. -
pb2(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies bottom padding of BsSpacing.s2. -
pb3(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies bottom padding of BsSpacing.s3. -
pb4(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies bottom padding of BsSpacing.s4. -
pb5(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies bottom padding of BsSpacing.s5. -
pe(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies right padding. -
pe0(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies zero right padding. -
pe1(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies right padding of BsSpacing.s1. -
pe2(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies right padding of BsSpacing.s2. -
pe3(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies right padding of BsSpacing.s3. -
pe4(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies right padding of BsSpacing.s4. -
pe5(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies right padding of BsSpacing.s5. -
ps(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies left padding. -
ps0(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies zero left padding. -
ps1(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies left padding of BsSpacing.s1. -
ps2(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies left padding of BsSpacing.s2. -
ps3(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies left padding of BsSpacing.s3. -
ps4(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies left padding of BsSpacing.s4. -
ps5(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies left padding of BsSpacing.s5. -
pt(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies top padding. -
pt0(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies zero top padding. -
pt1(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies top padding of BsSpacing.s1. -
pt2(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies top padding of BsSpacing.s2. -
pt3(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies top padding of BsSpacing.s3. -
pt4(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies top padding of BsSpacing.s4. -
pt5(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies top padding of BsSpacing.s5. -
px(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies horizontal padding. -
px0(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies zero horizontal padding. -
px1(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies horizontal padding of BsSpacing.s1. -
px2(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies horizontal padding of BsSpacing.s2. -
px3(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies horizontal padding of BsSpacing.s3. -
px4(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies horizontal padding of BsSpacing.s4. -
px5(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies horizontal padding of BsSpacing.s5. -
py(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies vertical padding. -
py0(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies zero vertical padding. -
py1(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies vertical padding of BsSpacing.s1. -
py2(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies vertical padding of BsSpacing.s2. -
py3(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies vertical padding of BsSpacing.s3. -
py4(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies vertical padding of BsSpacing.s4. -
py5(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsSpacingExtension extension
Applies vertical padding of BsSpacing.s5. -
rounded(
) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Applies a default border-radius of 0.375rem (6px), matching.rounded. -
rounded0(
) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Removes all border-radius, matching.rounded-0. -
rounded1(
) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Applies a small border-radius of 0.25rem (4px), matching.rounded-1. -
rounded2(
) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Applies a medium border-radius of 0.375rem (6px), matching.rounded-2. -
rounded3(
) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Applies a large border-radius of 0.5rem (8px), matching.rounded-3. -
rounded4(
) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Applies an extra-large border-radius of 1rem (16px), matching.rounded-4. -
rounded5(
) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Applies an extra-extra-large border-radius of 2rem (32px), matching.rounded-5. -
roundedBottom(
{double radius = 6.0}) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Applies border-radius only to the bottom side, matching.rounded-bottom. -
roundedCircle(
) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Applies a circular border-radius, matching.rounded-circle. -
roundedEnd(
{double radius = 6.0}) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Applies border-radius only to the end (right) side, matching.rounded-end. -
roundedPill(
) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Applies a pill-like border-radius (large value), matching.rounded-pill. -
roundedStart(
{double radius = 6.0}) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Applies border-radius only to the start (left) side, matching.rounded-start. -
roundedTop(
{double radius = 6.0}) → Widget -
Available on Widget, provided by the BsBorderExtension extension
Applies border-radius only to the top side, matching.rounded-top. -
size100(
) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets both width and height to 100% (double.infinity). Maps to Bootstrap's.w-100and.h-100. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
vh100(
BuildContext context) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets height to 100vh (100% of viewport height). -
vh50(
BuildContext context) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets height to 50vh (50% of viewport height). -
visible(
bool visible, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsDisplayExtension extension
Shows or hides the widget based onvisible. -
vw100(
BuildContext context) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets width to 100vw (100% of viewport width). -
vw50(
BuildContext context) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets width to 50vw (50% of viewport width). -
w(
double width) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets a fixed width for the widget. -
w100(
) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets the width to 100% (double.infinity). -
w25(
) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets the width to 25% of parent (FractionallySizedBox). -
w50(
) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets the width to 50% of parent (FractionallySizedBox). -
w75(
) → Widget -
Available on Widget, provided by the BsSizeExtension extension
Sets the width to 75% of parent (FractionallySizedBox).
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited