BsTableCell class
A configuration object for a table cell.
Constructors
- BsTableCell({BsVariant? variant, BsTableVerticalAlign? verticalAlign, bool active = false, bool isHeader = false, required Widget child})
-
Creates a BsTableCell.
const
- BsTableCell.header({BsVariant? variant, BsTableVerticalAlign? verticalAlign, bool active = false, bool isHeader = true, required Widget child})
-
Creates a BsTableCell marked as a header cell.
const
Properties
- active → bool
-
Whether this cell is currently active (highlighted).
final
- child → Widget
-
The content of the cell.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isHeader → bool
-
Whether this cell is a header cell (
<th>equivalent).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variant → BsVariant?
-
The variant for this specific cell.
final
- verticalAlign → BsTableVerticalAlign?
-
The vertical alignment for this cell.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited