BsTableRow class
A configuration object for a table row.
Constructors
-
BsTableRow({BsTableVariant? variant, BsTableVerticalAlign? verticalAlign, bool active = false, required List<
BsTableCell> children}) -
Creates a BsTableRow.
const
Properties
- active → bool
-
Whether this row is currently active (highlighted).
final
-
children
→ List<
BsTableCell> -
The cells in this row.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variant → BsTableVariant?
-
The variant for this specific row.
final
- verticalAlign → BsTableVerticalAlign?
-
The vertical alignment for cells in this row.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited