BsHeading constructor
const
BsHeading(})
Creates a BsHeading widget.
The text parameter is required and represents the heading's content.
The level defaults to BsHeadingLevel.h1.
The removeMargin parameter removes the default bottom margin if set to true.
Implementation
const BsHeading(
this.text, {
super.key,
this.level = BsHeadingLevel.h1,
this.color,
this.textAlign,
this.removeMargin = false,
});