BsButtonVariant enum
Variant types for BsButton.
Values
- primary → const BsButtonVariant
-
The primary button variant.
- secondary → const BsButtonVariant
-
The secondary button variant.
- success → const BsButtonVariant
-
The success button variant.
- danger → const BsButtonVariant
-
The danger button variant.
- warning → const BsButtonVariant
-
The warning button variant.
- info → const BsButtonVariant
-
The info button variant.
- light → const BsButtonVariant
-
The light button variant.
- dark → const BsButtonVariant
-
The dark button variant.
- outlinePrimary → const BsButtonVariant
-
Outline version of the primary variant.
- outlineSecondary → const BsButtonVariant
-
Outline version of the secondary variant.
- outlineSuccess → const BsButtonVariant
-
Outline version of the success variant.
- outlineDanger → const BsButtonVariant
-
Outline version of the danger variant.
- outlineWarning → const BsButtonVariant
-
Outline version of the warning variant.
- outlineInfo → const BsButtonVariant
-
Outline version of the info variant.
- outlineDark → const BsButtonVariant
-
Outline version of the dark variant.
- link → const BsButtonVariant
-
A text-only link variant.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BsButtonVariant> - A constant List of the values in this enum, in order of their declaration.