BsCardVariant enum
Color variants for BsCard.
Values
- primary → const BsCardVariant
-
Primary variant.
- secondary → const BsCardVariant
-
Secondary variant.
- success → const BsCardVariant
-
Success variant.
- danger → const BsCardVariant
-
Danger variant.
- warning → const BsCardVariant
-
Warning variant.
- info → const BsCardVariant
-
Info variant.
- light → const BsCardVariant
-
Light variant.
- dark → const BsCardVariant
-
Dark variant.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BsCardVariant> - A constant List of the values in this enum, in order of their declaration.