BsHeadingLevel enum

Heading levels corresponding to Bootstrap's <h1> through <h6> tags.

Inheritance
Available extensions

Values

h1 → const BsHeadingLevel

Heading 1 (<h1>) level.

h2 → const BsHeadingLevel

Heading 2 (<h2>) level.

h3 → const BsHeadingLevel

Heading 3 (<h3>) level.

h4 → const BsHeadingLevel

Heading 4 (<h4>) level.

h5 → const BsHeadingLevel

Heading 5 (<h5>) level.

h6 → const BsHeadingLevel

Heading 6 (<h6>) level.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BsHeadingLevel>
A constant List of the values in this enum, in order of their declaration.