BsModalSize enum
Defines the size variants of a Bootstrap modal.
Values
- sm → const BsModalSize
-
Small modal (max-width: 300px).
- md → const BsModalSize
-
Medium modal (default, max-width: 500px).
- lg → const BsModalSize
-
Large modal (max-width: 800px).
- xl → const BsModalSize
-
Extra large modal (max-width: 1140px).
- fullscreen → const BsModalSize
-
Fullscreen modal.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BsModalSize> - A constant List of the values in this enum, in order of their declaration.