BsRowJustify enum
Horizontal alignment options for BsRow columns.
Values
- start → const BsRowJustify
-
Align columns to the start (left) of the row.
- center → const BsRowJustify
-
Center columns horizontally in the row.
- end → const BsRowJustify
-
Align columns to the end (right) of the row.
- between → const BsRowJustify
-
Distribute columns evenly; first column is at the start, last is at the end.
- around → const BsRowJustify
-
Distribute columns evenly with equal space around them.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BsRowJustify> - A constant List of the values in this enum, in order of their declaration.