BsShadows class abstract
Bootstrap 5 Box-Shadow values. Source: https://getbootstrap.com/docs/5.3/utilities/shadows/
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
-
inset
→ const List<
BoxShadow> - Inset shadow (shadow-inset) $box-shadow-inset: inset 0 1px 2px rgba($black, .075);
-
lg
→ const List<
BoxShadow> - Large shadow (shadow-lg) $box-shadow-lg: 0 1rem 3rem rgba($black, .175);
-
regular
→ const List<
BoxShadow> - Regular shadow (shadow) $box-shadow: 0 .5rem 1rem rgba($black, .15);
-
sm
→ const List<
BoxShadow> - Small shadow (shadow-sm) $box-shadow-sm: 0 .125rem .25rem rgba($black, .075);