BsSpacing class abstract
Bootstrap 5 Spacing-System. Bootstrap uses a base of 1rem = 16px and multiplies by 0.25 steps. Source: https://getbootstrap.com/docs/5.3/utilities/spacing/
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- base → const double
- btnPaddingLg → const EdgeInsets
- btnPaddingMd → const EdgeInsets
- btnPaddingSm → const EdgeInsets
- s1 → const double
- s2 → const double
- s3 → const double
- s4 → const double
- s5 → const double