BsTypography class abstract
Bootstrap 5 Typography-System. Bootstrap uses system-near fonts — in Flutter we use the standard font and define sizes/weights exactly according to Bootstrap. Source: https://getbootstrap.com/docs/5.3/content/typography/
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- body → const TextStyle
- Ready-to-use TextStyle for body text with base size, normal weight, and base line height.
- btnLg → const TextStyle
- Ready-to-use TextStyle for large buttons with large font size, normal weight, and base line height.
- btnMd → const TextStyle
- Ready-to-use TextStyle for medium (default) buttons with base font size, normal weight, and base line height.
- btnSm → const TextStyle
- Ready-to-use TextStyle for small buttons with small font size, normal weight, and base line height.
- display1 → const double
- Font size for display-1 (80px, 5rem).
- display2 → const double
- Font size for display-2 (72px, 4.5rem).
- display3 → const double
- Font size for display-3 (64px, 4rem).
- display4 → const double
- Font size for display-4 (56px, 3.5rem).
- display5 → const double
- Font size for display-5 (48px, 3rem).
- display6 → const double
- Font size for display-6 (40px, 2.5rem).
- fontSizeBase → const double
- Base font size for body text (16px, 1rem).
- fontSizeLg → const double
- Large font size, used for large buttons and components (20px, 1.25rem).
- fontSizeSm → const double
- Small font size, used for small buttons and components (14px, 0.875rem).
- h1 → const double
- Font size for h1 headings (40px, 2.5rem).
- h2 → const double
- Font size for h2 headings (32px, 2rem).
- h3 → const double
- Font size for h3 headings (28px, 1.75rem).
- h4 → const double
- Font size for h4 headings (24px, 1.5rem).
- h5 → const double
- Font size for h5 headings (20px, 1.25rem).
- h6 → const double
- Font size for h6 headings (16px, 1rem).
- iconSizeBase → const double
- Base icon size for icons (16px).
- iconSizeLg → const double
- Large icon size (20px).
- iconSizeSm → const double
- Small icon size (14px).
- lineHeightBase → const double
- Default line height for body text (1.5).
- lineHeightDisplay → const double
- Line height for display headings (1.2).
- lineHeightHeadings → const double
- Line height for standard headings (1.2).
- lineHeightLg → const double
- Line height for large components (2.0).
- lineHeightSm → const double
- Line height for small components (1.25).
- weightBold → const FontWeight
- Font weight bold (w700).
- weightDisplay → const FontWeight
- Font weight for display headings (w300).
- weightHeadings → const FontWeight
- Default font weight for standard headings (w500).
- weightLight → const FontWeight
- Font weight light (w300).
- weightMedium → const FontWeight
- Font weight medium (w500).
- weightNormal → const FontWeight
- Font weight normal (w400).