BsTypography class abstract

Bootstrap 5 Typography-System. Bootstrap uses system-near fonts — in Flutter we use the standard font and define sizes/weights exactly according to Bootstrap. Source: https://getbootstrap.com/docs/5.3/content/typography/

Constructors

BsTypography()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

body → const TextStyle
btnLg → const TextStyle
btnMd → const TextStyle
btnSm → const TextStyle
fontSizeBase → const double
fontSizeLg → const double
fontSizeSm → const double
h1 → const double
h2 → const double
h3 → const double
h4 → const double
h5 → const double
h6 → const double
lineHeightBase → const double
lineHeightHeadings → const double
lineHeightLg → const double
lineHeightSm → const double
weightBold → const FontWeight
weightHeadings → const FontWeight
weightLight → const FontWeight
weightMedium → const FontWeight
weightNormal → const FontWeight