BsVerticalAlignExtension extension

Extension on Widget to provide inline vertical alignment utilities (Vertical Align).

These utilities return a WidgetSpan to align the widget inside inline text flows, matching Bootstrap's .align-* classes for inline elements.

on

Methods

alignBaseline({TextBaseline baseline = TextBaseline.alphabetic}) WidgetSpan

Available on Widget, provided by the BsVerticalAlignExtension extension

Aligns the baseline of the element with the baseline of its parent.
alignBottomInline() WidgetSpan

Available on Widget, provided by the BsVerticalAlignExtension extension

Aligns the bottom of the element with the bottom of the lowest element on the line.
alignMiddle() WidgetSpan

Available on Widget, provided by the BsVerticalAlignExtension extension

Centers the element vertically within the line.
alignTextBottom({TextBaseline baseline = TextBaseline.alphabetic}) WidgetSpan

Available on Widget, provided by the BsVerticalAlignExtension extension

Aligns the bottom of the element with the bottom of the parent element's font.
alignTextTop({TextBaseline baseline = TextBaseline.alphabetic}) WidgetSpan

Available on Widget, provided by the BsVerticalAlignExtension extension

Aligns the top of the element with the top of the parent element's font.
alignTopInline() WidgetSpan

Available on Widget, provided by the BsVerticalAlignExtension extension

Aligns the top of the element with the top of the tallest element on the line.