BsDisplayExtension extension
Extension on Widget to provide Bootstrap-like display and visibility utilities.
- on
Methods
-
dBlock(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsDisplayExtension extension
Convenient alias forgone(false). Maps to Bootstrap's.d-block. If a breakpoint is provided, it shows the widget from that breakpoint and up, and hides it on smaller screens (acting as a combination ofd-none d-{bp}-block). -
dNone(
[double? breakpoint]) → Widget -
Available on Widget, provided by the BsDisplayExtension extension
Convenient alias forgone(true). Maps to Bootstrap's.d-none. If a breakpoint is provided, it hides the widget from that breakpoint and up. -
gone(
bool gone, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsDisplayExtension extension
Hides the widget and removes it from the layout ifgoneis true. -
opacity(
double value, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsDisplayExtension extension
Sets the opacity of the widget. -
visible(
bool visible, [double? breakpoint]) → Widget -
Available on Widget, provided by the BsDisplayExtension extension
Shows or hides the widget based onvisible.