dBlock method
Convenient alias for gone(false).
Maps to Bootstrap's .d-block. If a breakpoint is provided, it shows the widget
from that breakpoint and up, and hides it on smaller screens
(acting as a combination of d-none d-{bp}-block).
Implementation
Widget dBlock([double? breakpoint]) {
if (breakpoint == null) return gone(false);
return Builder(
builder: (context) {
return Visibility(
visible: MediaQuery.sizeOf(context).width >= breakpoint,
maintainState: false,
child: this,
);
},
);
}